// Input_HSL.h: interface for the CInput_HSL class.
//
//////////////////////////////////////////////////////////////////////
#pragma once

#include "InputBase.h"

class CAdlinkCommon_HSL;

class CInput_HSL : public CInputBase
{
public:
    CInput_HSL(const CInputSetting& Setting);
    virtual ~CInput_HSL();

    // method to query Analog input voltage
    BOOL GetVoltage(double& dVoltage, int nRange) override;

    // method to set the last Analog Input Channel for HSL ONLY
    BOOL SetLastAICh(int nLastChannel) override;

    // method to set the Configuration of Analog Input for HSL ONLY
    BOOL SetAIConfig(int nSignalRange) override;

    int GetState() override;

    // method to start read
    BOOL StartRead() override;

    // method to get voltage only
    BOOL GetVoltageOnly(double& dVoltage, int nRange) override;

    // method to stop read
    BOOL StopRead() override;

private:
    std::unique_ptr<CAdlinkCommon_HSL> m_pCommon;
};
